@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: ColorSpace.pm,v 1.5 2004/06/07 19:44:36 fredo Exp $
+#   $Id: ColorSpace.pm,v 1.6 2004/06/15 09:14:41 fredo Exp $
 #
 #=======================================================================
 
@@ -44,7 +44,7 @@ BEGIN {
 
     @ISA = qw(PDF::API2::Basic::PDF::Array);
 
-    ( $VERSION ) = '$Revision: 1.5 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/07 19:44:36 $
+    ( $VERSION ) = '$Revision: 1.6 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/15 09:14:41 $
 
 }
 
@@ -127,6 +127,9 @@ alfred reibenschuh
 =head1
 
     $Log: ColorSpace.pm,v $
+    Revision 1.6  2004/06/15 09:14:41  fredo
+    removed cr+lf
+
     Revision 1.5  2004/06/07 19:44:36  fredo
     cleaned out cr+lf for lf
 
